==> DateTime-Locale-1.36.tar.gz: DateTime-Locale-1.36/share/su.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss a v",
    hmv => "h.mm a v",
    ms => "mm.ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "su",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} 'jam' {0}",
  datetime_format_long => "{1} 'jam' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Sen",
    "Sal",
    "Reb",
    "Kem",
    "Jum",
    "Sap",
    "Mng",
  ],
  day_format_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_format_wide => [
    "Sen\N{U+00e9}n",
    "Salasa",
    "Rebo",
    "Kemis",
    "Jumaah",
    "Saptu",
    "Minggu",
  ],
  day_stand_alone_abbreviated => [
    "Sen",
    "Sal",
    "Reb",
    "Kem",
    "Jum",
    "Sap",
    "Mng",
  ],
  day_stand_alone_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_stand_alone_wide => [
    "Sen\N{U+00e9}n",
    "Salasa",
    "Rebo",
    "Kemis",
    "Jumaah",
    "Saptu",
    "Minggu",
  ],
  era_abbreviated => [
    "SM",
    "M",
  ],
  era_narrow => [
    "SM",
    "M",
  ],
  era_wide => [
    "SM",
    "M",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sundanese",
  month_format_abbreviated => [
    "Jan",
    "P\N{U+00e9}b",
    "Mar",
    "Apr",
    "M\N{U+00e9}i",
    "Jun",
    "Jul",
    "Ags",
    "S\N{U+00e9}p",
    "Okt",
    "Nop",
    "D\N{U+00e9}s",
  ],
  month_format_narrow => [
    "J",
    "P",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "P\N{U+00e9}bruari",
    "Maret",
    "April",
    "M\N{U+00e9}i",
    "Juni",
    "Juli",
    "Agustus",
    "S\N{U+00e9}pt\N{U+00e9}mber",
    "Oktober",
    "Nop\N{U+00e9}mber",
    "D\N{U+00e9}s\N{U+00e9}mber",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "P\N{U+00e9}b",
    "Mar",
    "Apr",
    "M\N{U+00e9}i",
    "Jun",
    "Jul",
    "Ags",
    "S\N{U+00e9}p",
    "Okt",
    "Nop",
    "D\N{U+00e9}s",
  ],
  month_stand_alone_narrow => [
    "J",
    "P",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "P\N{U+00e9}bruari",
    "Maret",
    "April",
    "M\N{U+00e9}i",
    "Juni",
    "Juli",
    "Agustus",
    "S\N{U+00e9}pt\N{U+00e9}mber",
    "Oktober",
    "Nop\N{U+00e9}mber",
    "D\N{U+00e9}s\N{U+00e9}mber",
  ],
  name => "Sundanese",
  native_language => "Basa Sunda",
  native_name => "Basa Sunda",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "kuartal ka-1",
    "kuartal ka-2",
    "kuartal ka-3",
    "kuartal ka-4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "kuartal ka-1",
    "kuartal ka-2",
    "kuartal ka-3",
    "kuartal-ka 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/su.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h.mm\N{U+202f}a",
    Ehms => "E h.mm.ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h.mm\N{U+202f}a",
    hms => "h.mm.ss\N{U+202f}a",
    hmsv => "h.mm.ss\N{U+202f}a v",
    hmv => "h.mm\N{U+202f}a v",
    ms => "mm.ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "su",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Sen",
    "Sal",
    "Reb",
    "Kem",
    "Jum",
    "Sap",
    "Mng",
  ],
  day_format_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_format_wide => [
    "Sen\N{U+00e9}n",
    "Salasa",
    "Rebo",
    "Kemis",
    "Jumaah",
    "Saptu",
    "Minggu",
  ],
  day_stand_alone_abbreviated => [
    "Sen",
    "Sal",
    "Reb",
    "Kem",
    "Jum",
    "Sap",
    "Mng",
  ],
  day_stand_alone_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_stand_alone_wide => [
    "Sen\N{U+00e9}n",
    "Salasa",
    "Rebo",
    "Kemis",
    "Jumaah",
    "Saptu",
    "Minggu",
  ],
  era_abbreviated => [
    "SM",
    "M",
  ],
  era_narrow => [
    "SM",
    "M",
  ],
  era_wide => [
    "SM",
    "M",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sundanese",
  month_format_abbreviated => [
    "Jan",
    "P\N{U+00e9}b",
    "Mar",
    "Apr",
    "M\N{U+00e9}i",
    "Jun",
    "Jul",
    "Ags",
    "S\N{U+00e9}p",
    "Okt",
    "Nop",
    "D\N{U+00e9}s",
  ],
  month_format_narrow => [
    "J",
    "P",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "P\N{U+00e9}bruari",
    "Maret",
    "April",
    "M\N{U+00e9}i",
    "Juni",
    "Juli",
    "Agustus",
    "S\N{U+00e9}pt\N{U+00e9}mber",
    "Oktober",
    "Nop\N{U+00e9}mber",
    "D\N{U+00e9}s\N{U+00e9}mber",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "P\N{U+00e9}b",
    "Mar",
    "Apr",
    "M\N{U+00e9}i",
    "Jun",
    "Jul",
    "Ags",
    "S\N{U+00e9}p",
    "Okt",
    "Nop",
    "D\N{U+00e9}s",
  ],
  month_stand_alone_narrow => [
    "J",
    "P",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "P\N{U+00e9}bruari",
    "Maret",
    "April",
    "M\N{U+00e9}i",
    "Juni",
    "Juli",
    "Agustus",
    "S\N{U+00e9}pt\N{U+00e9}mber",
    "Oktober",
    "Nop\N{U+00e9}mber",
    "D\N{U+00e9}s\N{U+00e9}mber",
  ],
  name => "Sundanese",
  native_language => "Basa Sunda",
  native_name => "Basa Sunda",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "kuartal ka-1",
    "kuartal ka-2",
    "kuartal ka-3",
    "kuartal ka-4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "kuartal ka-1",
    "kuartal ka-2",
    "kuartal ka-3",
    "kuartal-ka 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => "44.1",
}
